const Mesa = require('vendor/Mesa.js');
const ShopifyGraphql = require('vendor/ShopifyGraphql.js');
const Shopify= require('vendor/Shopify.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {
  script = (payload, context) => {
    let vars = context.steps;
    let location = vars.shopify;

    let query = `
      query productWithVariantInventoryLevelsByLocation($productId:ID!, $locationId:ID!) {
        product(id:$productId) {
          id
          variants(first:20) {
            nodes {
              inventoryItem {
                id
                inventoryLevel(locationId:$locationId) {
                  quantities(names:"available") {
                    quantity
                  }
                }
              }
              inventoryQuantity
            }
          }
        }
      }
    `;
    
    const r = ShopifyGraphql.send(query, {
      "productId": `gid://shopify/Product/${vars.loop.product_id}`,
      "locationId": `gid://shopify/Location/${location.id}`
    }, {}, 'admin/api/2023-10/graphql.json');

    let sum = 0;
    for (let variant of r.data.product.variants.nodes) {
      let available = variant.inventoryItem.inventoryLevel.quantities[0].quantity;

      // If one variant has inventory -1 and another has 1, we don't want the sum to be zero - we want it to
      // be positive because at least one variant is in stock
      sum += (available > 0) ? available : 0;
    }

    Mesa.trigger.setTaskExternalData({
      "label": `Inventory at ${location.name}: ${sum}`
    })

    Mesa.output.next({"available": sum});
  }
}